@@ -8,6 +8,7 @@
 #include "rigidbody.h"
 #include "particle.h"
 #include <cmath>
+#include <Eigen/Geometry>
 
 namespace StepCore
 {
@@ -16,7 +17,8 @@ STEPCORE_META_OBJECT(LinearMotor, QT_TRANSLATE_NOOP("ObjectClass", "LinearMotor"
     STEPCORE_SUPER_CLASS(Item) STEPCORE_SUPER_CLASS(Force),
     STEPCORE_PROPERTY_RW(Object*, body, QT_TRANSLATE_NOOP("PropertyName", "body"), STEPCORE_UNITS_NULL, QT_TRANSLATE_NOOP("PropertyDescription", "Body"), body, setBody)
     STEPCORE_PROPERTY_RW(StepCore::Vector2d, localPosition, QT_TRANSLATE_NOOP("PropertyName", "localPosition"), QT_TRANSLATE_NOOP("Units", "m"), QT_TRANSLATE_NOOP("PropertyDescription", "Position of the motor on a body"), localPosition, setLocalPosition)
-    STEPCORE_PROPERTY_RW(StepCore::Vector2d, forceValue, QT_TRANSLATE_NOOP("PropertyName", "forceValue"), QT_TRANSLATE_NOOP("Units", "N"), QT_TRANSLATE_NOOP("PropertyDescription", "Value of the force, acting on the body"), forceValue, setForceValue))
+    STEPCORE_PROPERTY_RW(StepCore::Vector2d, forceValue, QT_TRANSLATE_NOOP("PropertyName", "forceValue"), QT_TRANSLATE_NOOP("Units", "N"), QT_TRANSLATE_NOOP("PropertyDescription", "Value of the force, acting on the body"), forceValue, setForceValue)
+    STEPCORE_PROPERTY_RW(bool, rigidlyFixed, QT_TRANSLATE_NOOP("PropertyName", "rigidlyFixed"), QT_TRANSLATE_NOOP("Units", ""), QT_TRANSLATE_NOOP("PropertyDescription", "Rotate the force vector in sync with body rotation"), isRigidlyFixed, setRigidlyFixed))
 
 STEPCORE_META_OBJECT(CircularMotor, QT_TRANSLATE_NOOP("ObjectClass", "CircularMotor"), QT_TRANSLATE_NOOP("ObjectDescription", "Circular motor: applies a constant torque to the body"), 0,
     STEPCORE_SUPER_CLASS(Item) STEPCORE_SUPER_CLASS(Force),
@@ -36,10 +38,18 @@ LinearMotor::LinearMotor(Object* body, const Vector2d& localPosition, const Vect
 
 void LinearMotor::calcForce(bool /*calcVariances*/)
 {
-     if(_p) _p->applyForce(_forceValue);
-     else if(_r) _r->applyForce(_forceValue,
-                        _r->pointLocalToWorld(_localPosition));
-        
+    if(_p) {
+        _p->applyForce(_forceValue);
+    } else if(_r) {
+        double angleDelta = _r->angle() - _lastBodyAngle;
+        _lastBodyAngle = _r->angle();
+        if (_rigidlyFixed) {
+            Eigen::Rotation2Dd rot(angleDelta);
+            _forceValue = rot * _forceValue;
+        }
+        _r->applyForce(_forceValue,
+                       _r->pointLocalToWorld(_localPosition));
+    }
 }
 
 void LinearMotor::setBody(Object* body)
@@ -49,17 +59,20 @@ void LinearMotor::setBody(Object* body)
             _body = body;
             _p = static_cast<Particle*>(body);
             _r = nullptr;
+            _lastBodyAngle = 0;
             return;
         } else if(body->metaObject()->inherits<RigidBody>()) {
             _body = body;
             _p = nullptr;
             _r = static_cast<RigidBody*>(body);
+            _lastBodyAngle = _r->angle();
             return;
         }
     }
     _body = nullptr;
     _p = nullptr;
     _r = nullptr;
+    _lastBodyAngle = 0;
 }    
 
 Vector2d LinearMotor::position() const
